<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 05/29/2004 *
 * ===================                          Last change: 11/26/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : autopurge.php                                    *
 * -------------------------------------------------------------------- *
 * Short description : Automatical purging of outdated mail links       *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auto-Loeschung von veralteten Mail-Links         *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Abort if autopurge is not active or disabled by admin
if ((!isExtensionActive('autopurge')) || (!isAutoPurgingActive()) || (getConfig('ap_del_mails') != 'Y')) {
	// Abort here
	return FALSE;
} // END - if

// Okay, let's check for deleted mails
$result_mails = sqlQuery("SELECT
	`sender`
FROM
	`{?_MYSQL_PREFIX?}_pool`
WHERE
	`data_type`='DELETED' AND
	(UNIX_TIMESTAMP() - `timestamp`) >= {?ap_dm_timeout?}
ORDER BY
	`sender` ASC", __FILE__, __LINE__);

// Init counter...
$deletedStats = '0';

// Is there "purged" mails?
if (!ifSqlHasZeroNums($result_mails)) {
	// Okay, check for their sender's
	while ($content = sqlFetchArray($result_mails)) {
		// Check now...
		if (!fetchUserData($content['sender'])) {
			// Okay we found some mails!
			sqlQueryEscaped("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_pool` WHERE `sender`=%s",
				array(bigintval($content['sender'])), __FILE__, __LINE__);

			// Get all affected (deleted) rows
			$deletedStats += sqlAffectedRows();
		} // END - if
	} // END - while
} // END - if

// Free memory
sqlFreeResult($result_mails);

// Now let's check for stats entries as well;
$result_mails = sqlQuery("SELECT
	`userid` AS `sender`
FROM
	`{?_MYSQL_PREFIX?}_user_stats`
WHERE
	(UNIX_TIMESTAMP() - `timestamp_send`) >= {?ap_dm_timeout?}
ORDER BY
	`userid` ASC", __FILE__, __LINE__);

// Is there "purged" mails?
if (!ifSqlHasZeroNums($result_mails)) {
	// Okay, check for their sender's
	while ($content = sqlFetchArray($result_mails)) {
		// Check now...
		if (!fetchUserData($content['sender'])) {
			// Okay we found some mails!
			sqlQueryEscaped("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_user_stats` WHERE `userid`=%s",
				array(bigintval($content['sender'])), __FILE__, __LINE__);

			// Get all affected (deleted) rows
			$deletedStats += sqlAffectedRows();

			// Reset query (to prevent possible errors) ...
			$result_mails = sqlQuery("SELECT
	`userid` AS `sender`
FROM
	`{?_MYSQL_PREFIX?}_user_stats`
WHERE
	(UNIX_TIMESTAMP() - `timestamp_send`) >= {?ap_dm_timeout?}
ORDER BY
	`userid` ASC", __FILE__, __LINE__);
		} // END - if
	} // END - while
} // END - if

// Free memory
sqlFreeResult($result_mails);

// Is there deleted mails and the admin want's to receive a notification
if (($deletedStats > 0) && (getConfig('ap_dm_notify') == 'Y')) {
	// Send out email to admin
	sendAdminNotification('{--ADMIN_AUTOPURGE_DELETE_MAILS_SUBJECT--}', 'admin_purge_del_mails', $deletedStats);
} // END - if

// [EOF]
?>
